#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-hunit
version: 0.3.0.2
id: test-framework-hunit-0.3.0.2-b5d0b731053bf414544ff6f4ae9e1d3a
key: testf_LUGDLxAtNSID59ylS3EMdB
license: BSD3
maintainer: Haskell Libraries <libraries@haskell.org>
homepage: https://batterseapower.github.io/test-framework/
synopsis: HUnit support for the test-framework package.
description:
    HUnit support for the test-framework package.
category: Testing
author: Max Bolingbroke <batterseapower@hotmail.com>
exposed: True
exposed-modules:
    Test.Framework.Providers.HUnit
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/test-framework-hunit-0.3.0.2
library-dirs: /usr/lib/ghc-7.10.3/site-local/test-framework-hunit-0.3.0.2
data-dir: /usr/share/arm-linux-ghc-7.10.3/test-framework-hunit-0.3.0.2
hs-libraries: HStest-framework-hunit-0.3.0.2-LUGDLxAtNSID59ylS3EMdB
depends:
    HUnit-1.3.1.1-21d4c913eac2236e948873e3db41c801
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    extensible-exceptions-0.1.1.4-8159918b63d70675389129eaecbf720a
    test-framework-0.8.1.1-a9fe3ef1175e4639905fc641f904c6e2
haddock-interfaces: /usr/share/doc/haskell-test-framework-hunit/html/test-framework-hunit.haddock
haddock-html: /usr/share/doc/haskell-test-framework-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
